from ...utils.abbreviated_enum import AbbreviatedEnum


class PreCleaningOptions(AbbreviatedEnum):
    heavy_cleaning = ("Heavy Cleaning", "H")
    light_cleaning = ("Light Cleaning", "L")
    no_pre_cleaning = ("No Pre-Cleaning", "N")
    not_known = ("Not Known", "X")
    other = ("Other", "Z")
